@@ -2,7 +2,7 @@ from .rawdevart_com_old import RawDevArtComOld
 
 
 class ISekaiScanCom(RawDevArtComOld):
-    _chapter_selector = r'/chapter-(\d+(?:-[\w\-]+)?)'
+    _chapter_selector = r'/(?:chapter-)?(\d+(?:[\a-zA-Z\.-]*?\d+)?(?:-\w+)?)/'
 
     def get_files(self):
         parser = self.html_fromstring(self.chapter)
